'use strict';
const assert = require('assert-plus');

const create = (ecs) => {
  const get = (name, cluster) => {
    assert.string(name, 'service name is required');
    assert.string(cluster, 'cluster name is required');

    return ecs.describeServices({
      services: [name],
      cluster
    }).promise().then(res => res.services[0] || {});
  };

  const update = (params) => {
    assert.string(params.service, 'service name is required');
    assert.string(params.cluster, 'cluster name is required');

    return ecs.updateService(params).promise();
  };

  const waitForDeployment = (name, cluster) => {
    return ecs.waitFor('servicesStable', {
      services: [name],
      cluster
    }).promise();
  };

  return {
    get,
    update,
    waitForDeployment
  };
};

module.exports = {
  create
};
