'use strict';
// use ENV as the default config
const defaultConfig = () => {
  return {
    get: (key) => process.env[key]
  };
};

const getMatches = (string, regex, index) => {
  // default to the first capturing group
  index || (index = 1);
  const matches = [];
  let match = regex.exec(string);
  while (match) {
    matches.push(match[index]);
    match = regex.exec(string);
  }
  return matches;
};

const basicMatcher = {
  pattern: /@@(\w+)@@/g,
  toPlaceHolder: (str) => new RegExp(`@@${str}@@`, 'g')
};

const processFile = (raw, config, matcher) => {
  matcher = matcher || basicMatcher;
  config = config || defaultConfig();
  const matches = getMatches(raw, matcher.pattern);

  const rendered = matches.reduce((acc, elem) => {
    const value = config.get(elem);
    if (value === undefined) {
      throw new Error(`Could not find ${elem} in config`);
    }

    const regex = matcher.toPlaceHolder(elem);
    return acc.replace(regex, value);
  }, raw);

  return JSON.parse(rendered);
};

module.exports = {
  process: processFile,
  matcher: {
    basic: basicMatcher
  }
};
