'use strict';
const assert = require('assert-plus');

const taskArnPattern = /arn:aws:ecs:[A-Za-z0-9-]+:\d+:task-definition\/([A-Za-z-]+):(\d+)/g;
const parseTaskArn = (arn) => {
  const match = taskArnPattern.exec(arn);
  return (match) ? {
    family: match[1],
    revision: match[2],
    arn: match[0]
  } : match;
};

const parseEnv = (content) => {
  return content.trim().split('\n')
                .filter(line => line.length > 0 && !line.startsWith('#'))
                .map(line => {
                  const parts = line.split('=');
                  assert.bool(parts.length == 2, 'Invalid line in file. All lines must be of the form A=B');
                  return {
                    name: parts[0].trim(),
                    value: parts[1].trim()
                  };
                });
};


module.exports = {
  parseTaskArn,
  parseEnv
};
